/*************************************************
*                                                *
*  EasyBMP Cross-Platform Windows Bitmap Library * 
*                                                *
*  Author: Paul Macklin                          *
*   email: pmacklin@math.uci.edu                 *
*                                                *
*    file: EasyBMP_DataStructures.h              *
*    date: 5-2-2005                              *
* version: 0.61                                  *
*                                                *
*   License: LGPL v 2.2                          *
* Copyright: 2005 by the EasyBMP Project         * 
*                                                *
* description: Defines basic data structures for *
*              the BMP class                     *
*                                                *
*************************************************/

#ifndef _WINGDI_H
#define _SELF_DEFINED_BMP_DATA_TYPES 1
#define _WINGDI_H
 typedef unsigned char BYTE;
 typedef unsigned short WORD;
 typedef unsigned long DWORD;
#endif 

// it's easier to use a struct than a class
// because we can read/write all four of the bytes 
// at once (as we can count on them being continuous 
// in memory

typedef struct RGBApixel {
	BYTE	Blue;
	BYTE	Green;
	BYTE	Red;
	BYTE	Alpha;
} RGBApixel; 

class BMFH{
public:
 WORD	bfType;
 DWORD	bfSize;
 WORD	bfReserved1;
 WORD	bfReserved2;
 DWORD	bfOffBits; 

 BMFH();
 void display( void );
};

BMFH::BMFH()
{
 bfType = 19778;
 bfReserved1 = 0;
 bfReserved2 = 0;
}

class BMIH{
public:
 DWORD biSize;
 DWORD biWidth;
 DWORD biHeight;
 WORD biPlanes;
 WORD biBitCount;
 DWORD biCompression;
 DWORD biSizeImage;
 DWORD biXPelsPerMeter;
 DWORD biYPelsPerMeter;
 DWORD biClrUsed;
 DWORD biClrImportant;

 BMIH();
 void display( void );
};

BMIH::BMIH()
{
 biPlanes = 1;
 biCompression = 0;
 biXPelsPerMeter = 0; // change this?
 biYPelsPerMeter = 0; // change this?
 biClrUsed = 0;
 biClrImportant = 0;
}

void BMIH::display( void )
{
 cout << "biSize: " << (int) biSize << "\n"
      << "biWidth: " << (int) biWidth << "\n"
      << "biHeight: " << (int) biHeight << "\n"
      << "biPlanes: " << (int) biPlanes << "\n"
      << "biBitCount: " << (int) biBitCount << "\n"
      << "biCompression: " << (int) biCompression << "\n"
      << "biSizeImage: " << (int) biSizeImage << "\n"
      << "biXPelsPerMeter: " << (int) biXPelsPerMeter << "\n"
      << "biYPelsPerMeter: " << (int) biYPelsPerMeter << "\n"
      << "biClrUsed: " << (int) biClrUsed << "\n"
      << "biClrImportant: " << (int) biClrImportant << "\n\n";
}

void BMFH::display( void )
{
 cout << "bfType: " << (int) bfType << "\n"
      << "bfSize: " << (int) bfSize << "\n"
      << "bfReserved1: " << (int) bfReserved1 << "\n"
      << "bfReserved2: " << (int) bfReserved2 << "\n"
      << "bfOffBits: " << (int) bfOffBits << "\n\n";
}
